Translate Toolkit 3.14.4
************************

*Released on 20 December 2024*

This release contains improvements and bug fixes.

Changes
=======

Formats and Converters
----------------------

- Android

  - Improve escape sequences handling

Contributors
============

This release was made possible by the following people:

Michal Čihař
